@@ -14,12 +14,12 @@ def find_equilibrium(obj):
     I = obj.calc_I(obj.calc_pH())
 
     # Try to bound the true answer.
-    b1 = obj.equil_offset(0)
-    b2 = obj.equil_offset(2*I)
+    b1 = obj.equil_offset(0.)
+    b2 = obj.equil_offset(2.*I)
 
     # If the answer is in the bound, use brentq. Otherwise, use newton.
     # If brentq doesn't converge, use newton.
-    if ((b1 < 0) ^ (b2 < 0)):
+    if ((b1 < 0.) ^ (b2 < 0.)):
         I, r = brentq(obj.equil_offset, 0, 2*I, full_output=True)
         if not r.converged:
             I = newton(obj.equil_offset, I)
